******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* Prepare law adoption file and analysis 

******************************************************************************************************************************************************************************
* Set directory (only necessary if you are not executing this file from "00_CPAMob_Master.do")

cd "/CPAMobility/"

******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* Data imports and preparation

******************************************************************************************************************************************************************************
* Import laws passed (hand collected, source: http://knowledgecenter.csg.org/kc/category/content-type/bos-archive)

import excel "./Data/LawPrediction/LawsByState.xls", sheet("Sheet1") firstrow clear
drop if State =="Dist. of Columbia" /*no available data*/

******************************************************************************************************************************************************************************
* Merge in FIPS indentifiers 

rename Year year
preserve
use "./Data/Helper/LawDummiesCensusState.dta", clear 
keep State year area_fips lq_annual_avg_emplvl
tempfile merger 
save `merger'

restore 
capture drop _merge 
merge 1:1 State year using `merger'
keep if _merge == 3 /*all merged from master*/

******************************************************************************************************************************************************************************
* Merge in macro controls

capture drop _merge
merge 1:1 area_fips year using "./Data/LawPrediction/macrocontrols.dta"
keep if _merge == 3  /*all from master are merged*/
drop _merge  

******************************************************************************************************************************************************************************
* Merge in BDS

preserve
import delimited "./Data/LawPrediction/Data_BDS/bds_e_st_release.csv", encoding(ISO-8859-1)clear
gen firm_birth = estabs_entry / estabs
gen jobcreation_netbirth = net_job_creation_rate
xtset state year2, yearly
foreach var of varlist firm_birth jobcreation_netbirth {
	gen L1_`var' = L.`var'

}
keep if year >= 2003 & year <= 2015
keep state year2 firm_birth jobcreation_netbirth L1_*
* prep for merge
tostring state, gen(area_fips)
replace area_fips = "0" + area_fips if strlen(area_fips) == 1
replace area_fips = area_fips + "000" 
drop state 
rename year2 year
tempfile bds
save `bds'

restore 
merge 1:1 area_fips year using `bds'
assert _merge != 1 
keep if _merge == 3
drop _merge

******************************************************************************************************************************************************************************
* Merge in political economy predictors

preserve
import excel "./Data/LawPrediction/CPAMob_PoliticalEconomy.xlsx", sheet("Sheet1") firstrow clear
drop K L M N O P Q /*drop notes from hand collection*/
drop if State == "" /*drop empty lines in hand collection sheet*/
drop if State == "DC" /*no legislation vars, as before*/
tempfile polecon
save `polecon'

restore 
merge m:1 State using `polecon' 
keep if _merge == 3 
drop _merge  


******************************************************************************************************************************************************************************
* Merge in State Board of Accountancy predictors from Colbert and Murray (2013)

* interim step: merge in cross walk file to merge with Colbert and Murray (2013) data
preserve
import excel "./Data/LawPrediction/StatesPostalCodeCrosswald.xlsx", sheet("Sheet1") clear
gen StatePostal = substr(A, -2, .)
gen State = substr(A, 1, strlen(A) - 5)
tempfile postcode
save `postcode'
restore
merge m:1 State using `postcode'
assert _merge != 1 
keep if _merge == 3
drop _merge 

* merge in
merge m:1 StatePostal using "./Data/LawPrediction/ColbertMurray.dta"

******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* Variable prep and analysis

******************************************************************************************************************************************************************************
* Variable prep 

* Set STCox structure for checking
egen id = group(State)
gen coxtime = year - 2002 

* Set failure event
sort State year
by State: gen CPAMob = (_n ==_N)
stset coxtime, id(id) failure(CPAMob==1)
* check Cox structure
* sts graph

* Prep bill load variables
replace Session = "1" if Session =="" 
gen nosessionid = (Session == "na" | Session == "0")
* When there is no session, nothing can be passed
foreach var of varlist IntroBill IntroResol EnactBill EnactResol {
	replace `var' = "0" if nosessionid == 1

}
replace LengthSession = "0" if nosessionid == 1 

* Prep Dem / Rep variables
destring Senate_Dem, replace force
destring Senate_Rep, replace force
gen Senate_Total = Senate_Dem + Senate_Rep
gen Senate_Dem_Share = Senate_Dem / Senate_Total
* For Nebraska, assume equal splits (house / senate and rep / dem)
replace Senate_Total = 25 if State == "Nebraska"
replace Senate_Dem_Share = 0.5 if State == "Nebraska"

* House share and total
destring House_Dem, replace force
destring House_Rep, replace force
gen House_Total = House_Dem + House_Rep
gen House_Dem_Share = House_Dem / House_Total
* For Nebraska, assume equal splits (house / senate and rep / dem)
replace House_Total = 25 if State == "Nebraska"
replace House_Dem_Share = 0.5 if State == "Nebraska"

* Total state split
gen HouseSenate_Dem = House_Dem + Senate_Dem
gen HouseSenate_Rep = House_Rep + Senate_Rep
gen HouseSenate_Total = HouseSenate_Dem + HouseSenate_Rep
gen HouseSenate_Dem_Share = HouseSenate_Dem / HouseSenate_Total
replace HouseSenate_Total = 49 if State == "Nebraska"
replace HouseSenate_Dem_Share = 0.5 if State == "Nebraska"

* Bills enacted / introduced 
destring EnactBill, replace force
destring IntroBill, replace force
gen logbills = log(1 + IntroBill)
gen logenact = log(1 + EnactBill)

* Pol economy: Mob Task Force
gen mobilitytaskforce = (MobTaskForce != "0") 

* Pol economy: board structure
gen CPAinBoard = CPABoard / TotalBoard
gen Big4inBoard = Big4Board / TotalBoard

* Pol economy: Colbert / Murray 
gen pubprac = real(PUBPRAC) 
gen fundingautonomy = FUND_AUT
gen localCPAs = NO_LOCAL / (NO_NAT + NO_LOCAL) 

******************************************************************************************************************************************************************************
* Wage and employment trends, difference to mean

preserve

* import QCEW state-level data for years 2000 and 2005
foreach i in 2000 2005 {
	import delimited "./Data/Census/Data_QCEW/QCEW_RAWData/`i'.annual.singlefile.csv", stringcols(_all) clear
	keep if industry_code == "541211" /*keep CPAs only*/
	keep if own_code == "5" /*keep only privately owned*/
	keep if agglvl_code == "58" /*keep only state-level 6 digits*/
	gen excludestate = (area_fips == "51000" | area_fips == "39000" | area_fips == "78000" | area_fips == "72000" | area_fips == "15000")
	drop if excludestate == 1 /*align with main sample*/
	rename avg_annual_pay pay
	rename annual_avg_emplvl emp
	keep area_fips year pay emp
	tempfile qcew`i'
	save "`qcew`i''"
}
use "`qcew2000'", clear
append using "`qcew2005'"
ds area_fips, not
foreach v of var `r(varlist)' {
	destring `v', replace
}
egen state_id = group(area_fips)
xtset state_id year, yearly
gen logpay = log(pay)
gen logemp = log(emp)

* gen difference over time
gen d5logpay = logpay - L5.logpay
gen d5logemp = logemp - L5.logemp

* gen difference to mean
keep if year == 2005 /*calc diffs to national */
egen logpaymean = mean(logpay)
egen logempmean = mean(logemp)
gen logpaydiff = logpay - logpaymean
gen logempdiff = logemp - logempmean
keep area_fips d*log* logpaydiff logempdiff
tempfile qcewcontrols
save `qcewcontrols'
restore
capture drop _merge 
merge m:1 area_fips using  `qcewcontrols'
keep if _merge == 3

******************************************************************************************************************************************************************************
* Prediction analysis 

* Table 1, Panel B: CPA Mobility Adoption Prediction 
preserve
qui stcox logpaydiff logempdiff d5logpay d5logemp pubprac localCPAs i.mobilitytaskforce i.fundingautonomy L1_unemprate L1_realgdp L1_firm_birth L1_jobcreation_netbirth Senate_Dem_Share House_Dem_Share logbills logenact, cluster(id)
keep if (e(sample)) == 1 /*estimate full model to ascertain equal obs across specs*/
eststo clear
eststo: stcox logpaydiff logempdiff d5logpay d5logemp, cluster(id)
eststo: stcox pubprac localCPAs i.mobilitytaskforce i.fundingautonomy, cluster(id)
eststo: stcox L1_unemprate L1_realgdp L1_firm_birth L1_jobcreation_netbirth
eststo: stcox Senate_Dem_Share House_Dem_Share logbills logenact, cluster(id)
eststo: stcox logpaydiff logempdiff d5logpay d5logemp pubprac localCPAs i.mobilitytaskforce i.fundingautonomy L1_unemprate L1_realgdp L1_firm_birth L1_jobcreation_netbirth Senate_Dem_Share House_Dem_Share logbills logenact, cluster(id)
esttab using "./Output/Table1_PanelB.csv", label b(3) se(3) pa star(* 0.10 ** 0.05 *** 0.01) pr2 nodep nonote nomti noli nogap alignment(c) replace eform
restore 

