******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* QCEW MSA-level prep and analysis

******************************************************************************************************************************************************************************
* Set directory (only necessary if you are not executing this file from "00_CPAMob_Master.do")

cd "/CPAMobility/"

******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* Import and clean data

******************************************************************************************************************************************************************************
* Import Census MSA data

filelist, dir("./Data/Census/Data_QCEW/QCEW_RAWData/") pat("*.csv") save("./Data/Census/Data_QCEW/QCEW_RAWData/csv_qcew_cpas_datasets.dta") replace

use "./Data/Census/Data_QCEW/QCEW_RAWData/csv_qcew_cpas_datasets.dta", clear 
local obs = _N
forvalues i=1/`obs' {
	use "./Data/Census/Data_QCEW/QCEW_RAWData/csv_qcew_cpas_datasets.dta" in `i', clear
	local d = dirname + "/" + filename
	local f = filename 
	import delimited using "`d'", stringcols(_all) clear 
	gen filename = "`f'"
	keep if agglvl_code == "48" /*keep only MSA-level 6 digits -- Census codes available here: https://data.bls.gov/cew/doc/titles/agglevel/agglevel_titles.htm*/
	keep if own_code == "5" /*keep only privately owned*/
	keep if industry_code == "541211" | industry_code == "541110" /*keep only CPAs and lawyers*/

	foreach var of varlist *disclosure_code {
		gen `var'_str = "null" 
		if missing(`var') {
			replace `var'_str = "blank"
		}
		else {
			replace `var'_str = "N"
		}
		drop `var'
	}
	tempfile save`i'
	save "`save`i''"
}

use "`save1'", clear
forvalues i=2/`obs' {
	append using "`save`i''"
}

******************************************************************************************************************************************************************************
* Clean up and adjust variable formatting

drop oty_* lq_* filename qtr disclosure_code_st size_code own_code total_annual_wages taxable_annual_wages annual_avg_wkly_wage annual_contributions 

foreach var of varlist year annual_avg_estabs annual_avg_emplvl avg_annual_pay {
	destring `var', replace 
}

******************************************************************************************************************************************************************************
* Merge in GDP MSA 

preserve
import delimited "./Data/Controls/bea_gdp_annual_naicsall_msa_clean.csv", encoding(ISO-8859-1)clear stringc(_all)
foreach var of varlist v3-v19 {
   local x : variable label `var' 
   rename `var' msagdp`x'
   destring msagdp`x', replace force
}
reshape long msagdp, i(geofips geoname) j(year)
* adjust to msa fips 
gen area_fips = "C" + substr(geofips, 1, 4)
drop geofips
tempfile msagdp
save `msagdp'
restore 
merge m:1 area_fips year using `msagdp'
drop if _merge == 2
drop _merge 

******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* Analysis and variable preparation

* gen industry ID 
encode industry_code, gen(industry_id) label(industry_id)

* rename variables
gen pay = avg_annual_pay
gen logpay = log(pay)
gen emp = annual_avg_emplvl
gen logemp = log(emp)
gen logmsagdp = log(msagdp)

* difference variables
capture drop msa_industry_id 
egen msa_industry_id = group(area_fips industry_id)
xtset msa_industry_id year, yearly
foreach var of varlist logpay logmsagdp {
	capture gen d1`var' = (`var' - L1.`var') 
}

* IDs and screen
gen cpa = (industry_code == "541211")
gen lawyer = (industry_code == "541110")
keep if cpa == 1 | lawyer == 1 


******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* Helper variables and screen

* est periods
gen postperiod = (year >= 2014)
gen prepreriod = (year >= 2002 & year <= 2005)
gen estperiod = (prepreriod == 1 | postperiod == 1)

* label for outputs
label define cpal 0 "Lawyers" 1 "CPAs" 
label values cpa cpal 
label define postperiodl 0 "Pre-Period" 1 "Post-Period" 
label values postperiod postperiodl 
label define preperiodl 0 "Post-Period" 1 "Pre-Period" 
label values prepreriod preperiodl 
label var d1logpay ""

* min data availablity criterion
egen msa_id = group(area_fips)
gen inclobs = (!missing(d1logpay))
bysort msa_id cpa estperiod: egen totalinclobs = total(inclobs)
keep if totalinclobs >= 5

* calc empshares
bysort cpa year: egen totalemp = total(emp)
gen empshare = emp / totalemp


******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* Figure 3, Panel A and B: Visual sens analysis 

binscatter d1logpay d1logmsagdp [aw = empshare] if prepreriod == 1 & cpa == 1 ///
	, reportreg yscale(r(0.01 0.06)) ylabel(0.01(0.01)0.06) xscale(r(-0.05 0.1)) xlabel(-0.05(0.05)0.1) ///
	title("CPAs: Pre-Period") ytitle("∆LogWage") xtitle("∆LogGDP") 
graph export "./Output/Figure3_PanelA-1.pdf", as(pdf) replace
graph close

binscatter d1logpay d1logmsagdp [aw = empshare] if postperiod == 1 & cpa == 1 ///
	, reportreg yscale(r(0.01 0.06)) ylabel(0.01(0.01)0.06) xscale(r(-0.05 0.1)) xlabel(-0.05(0.05)0.1) ///
	title("CPAs: Post-Period") ytitle("∆LogWage") xtitle("∆LogGDP") 
graph export "./Output/Figure3_PanelA-2.pdf", as(pdf) replace
graph close

binscatter d1logpay d1logmsagdp [aw = empshare] if prepreriod == 1 & lawyer == 1 /// 
	, reportreg yscale(r(0.01 0.06)) ylabel(0.01(0.01)0.06) xscale(r(-0.05 0.1)) xlabel(-0.05(0.05)0.1) ///
	title("Lawyers: Pre-Period") ytitle("∆LogWage") xtitle("∆LogGDP") 
graph export "./Output/Figure3_PanelB-1.pdf", as(pdf) replace
graph close

binscatter d1logpay d1logmsagdp [aw = empshare] if postperiod == 1 & lawyer == 1 ///
	, reportreg yscale(r(0.01 0.06)) ylabel(0.01(0.01)0.06) xscale(r(-0.05 0.1)) xlabel(-0.05(0.05)0.1) ///
	title("Lawyers: Post-Period") ytitle("∆LogWage") xtitle("∆LogGDP") 
graph export "./Output/Figure3_PanelB-2.pdf", as(pdf) replace
graph close


******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* Table 5, Panel A: Sens analysis regression

gen d1logmsagdp_post = d1logmsagdp * postperiod
gen d1logmsagdp_pre = d1logmsagdp * prepreriod

gen d1logmsagdp_cpa = d1logmsagdp * cpa
gen d1logmsagdp_lawyer = d1logmsagdp * lawyer
gen d1logmsagdp_cpa_post = d1logmsagdp * cpa * postperiod
gen d1logmsagdp_lawyer_post = d1logmsagdp * lawyer * postperiod

* Desc Stats 
gen cpalawyer = (cpa == 1 | lawyer == 1)
tabstat pay logpay d1logpay if cpa == 1 & estperiod == 1 & !missing(d1logpay) & !missing(d1logmsagdp), s(n mean sd p1 p25 p50 p75 p99) columns(statistics)
tabstat pay logpay d1logpay if lawyer == 1 & estperiod == 1 & !missing(d1logpay) & !missing(d1logmsagdp), s(n mean sd p1 p25 p50 p75 p99) columns(statistics)
tabstat msagdp logmsagdp d1logmsagdp if estperiod == 1 & !missing(d1logpay) & cpalawyer == 1, s(n mean sd p1 p25 p50 p75 p99) columns(statistics)

* Table 5, Panel A: Reg | profession 
eststo clear
eststo: reg d1logpay d1logmsagdp_post d1logmsagdp postperiod [aw = empshare] if cpa == 1 & estperiod == 1, cluster(msa_id)
eststo: reg d1logpay d1logmsagdp_post d1logmsagdp postperiod [aw = empshare] if lawyer == 1 & estperiod == 1, cluster(msa_id)
esttab using "./Output/Table5_PanelA.csv", label b(3) se(3) pa star(* 0.10 ** 0.05 *** 0.01) ar2 nodep nonote nomti noli nogap alignment(c) replace

* Aux reg: for difference in coefficient test 
capture egen cpa_year_id = group(cpa year)
capture egen cpa_period_id = group(cpa postperiod)
capture egen msa_id = group(area_fips)
capture egen msa_cpa_id = group(area_fips cpa)

reg d1logpay d1logmsagdp_cpa_post d1logmsagdp_cpa d1logmsagdp_lawyer_post d1logmsagdp_lawyer i.cpa i.postperiod i.postperiod#i.cpa [aw = empshare] if estperiod == 1, cluster(msa_id)
test d1logmsagdp_cpa_post = d1logmsagdp_lawyer_post


******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* Table 5, Panel B: Volatility analysis 

eststo clear

* Table 5, Panel B, Col 1
preserve
keep if estperiod == 1
local testvar d1logpay
collapse (sd) `testvar' [aw = emp], by(cpa year prepreriod postperiod)
gen cpapost = postperiod * cpa
eststo: reg `testvar' cpapost cpa post, vce(robust)
restore 

* Table 5, Panel B, Col2
preserve
keep if estperiod == 1
local testvar d1logpay
collapse (iqr) `testvar' [aw = emp], by(cpa year prepreriod postperiod)
gen cpapost = postperiod * cpa
eststo: reg `testvar' cpapost cpa post, vce(robust)
restore 
esttab using "./Output/Table5_PanelB.csv", label b(3) se(3) pa star(* 0.10 ** 0.05 *** 0.01) ar2 nodep nonote nomti noli nogap alignment(c) replace


******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* Table 5, Panel C: Convergence analysis 

eststo clear

* Tabel 5, Panel C, Col1 
preserve
keep if estperiod == 1
local testvar logpay
collapse (sd) `testvar' [aw = emp], by(cpa year prepreriod postperiod)
gen cpapost = postperiod * cpa
eststo: reg `testvar' cpapost cpa postperiod, vce(robust)
restore 

* Tabel 5, Panel C, Col2 
preserve
keep if estperiod == 1
local testvar logpay
collapse (iqr) `testvar' [aw = emp], by(cpa year prepreriod postperiod)
gen cpapost = postperiod * cpa
eststo: reg `testvar' cpapost cpa postperiod, vce(robust)
restore 
esttab using "./Output/Table5_PanelC.csv", label b(3) se(3) pa star(* 0.10 ** 0.05 *** 0.01) ar2 nodep nonote nomti noli nogap alignment(c) replace

